<!DOCTYPE html>
<html>

<head>
  <meta charset="utf-8">
  <meta name="viewport" content="width=device-width, initial-scale=1.0">
  <title>pyp5js server</title>
</head>

<body>
  <h2>Your sketch was created with success!!!</h2>
  <p>Now you can start to draw, I mean, to code!</p>
  <p>Edit your Python sketch file located at {{ files.sketch_py.resolve() }} and have fun!</p>
  <p><a href="{{ sketch_url }}">Click here</a> to see your results or <a href="/">go back to the home</a>.</p>
</body>

</html>

